@@ -1,7 +1,7 @@
 (*----------------------------------------------------------------------------
-   Copyright (c) 2007-2008, Daniel C. Bünzli. All rights reserved.
+   Copyright (c) 2007-2009, Daniel C. Bünzli. All rights reserved.
    Distributed under a BSD license, see license at the end of the file.
-   Xmlm version 1.0.1
+   Xmlm version 1.0.2
   ----------------------------------------------------------------------------*)
 
 (** Streaming XML IO.  
@@ -17,7 +17,7 @@
     Consult the {{:#io}features and limitations} and {{:#ex}examples} 
     of use.
 
-    {e Version 1.0.1 - daniel.buenzl i\@erratique.ch }
+    {e Version 1.0.2 - daniel.buenzl i\@erratique.ch }
 
     {b References.}
 
@@ -576,7 +576,9 @@ let ex_ns = (Xmlm.ns_xmlns, "ex"), "http://example.org/ex"]}
     {ul 
     {- The best options to do an input/output round trip
        and preserve as much information as possible is to 
-       input with [strip = false] and output with [indent = None].}}
+       input with [strip = false] and output with [indent = None].}
+    {- Complete whitespace control on output is achieved 
+       with [indent = None] and suitable [`Data] signals}}
 *)
 
 (** {1:ex Examples} 
@@ -757,7 +759,7 @@ let out_w3c_bureaucrats dst bl =
 *)
 
 (*----------------------------------------------------------------------------
-  Copyright (c) 2007-2008, Daniel C. Bünzli
+  Copyright (c) 2007-2009, Daniel C. Bünzli
   All rights reserved.
 
   Redistribution and use in source and binary forms, with or without
